@@ -8,7 +8,7 @@ from .fs2json import FS2Json
 from . import utemplates as ut
 
 
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 __static_version__ = '1.0.4'
 
 fs2json = FS2Json()
@@ -59,7 +59,7 @@ def logout(ctx: Context):
 def index(ctx: Context):
     return dict(
         web23py='web3py',
-        title='Vue3pyj',
+        title='PYJSAW',
         static_version='',
         app_root=ctx.get('base_url')
     )
